@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2000, 2007 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2000, 2007 David Faure <faure@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License version 2 or at your option version 3 as published by
-   the Free Software Foundation.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
 */
 
 // Own
@@ -197,7 +184,7 @@ void FileTypeDetails::updateIcon(const QString &icon)
         m_item->setIcon(icon);
     }
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void FileTypeDetails::updateDescription(const QString &desc)
@@ -208,7 +195,7 @@ void FileTypeDetails::updateDescription(const QString &desc)
 
     m_mimeTypeData->setComment(desc);
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void FileTypeDetails::addExtension()
@@ -225,7 +212,7 @@ void FileTypeDetails::addExtension()
         patt += ext;
         m_mimeTypeData->setPatterns(patt);
         updateRemoveButton();
-        emit changed(true);
+        Q_EMIT changed(true);
     }
 }
 
@@ -242,7 +229,7 @@ void FileTypeDetails::removeExtension()
     m_mimeTypeData->setPatterns(patt);
     delete extensionLB->takeItem(extensionLB->currentRow());
     updateRemoveButton();
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void FileTypeDetails::slotAutoEmbedClicked(int button)
@@ -255,7 +242,7 @@ void FileTypeDetails::slotAutoEmbedClicked(int button)
 
     updateAskSave();
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void FileTypeDetails::updateAskSave()
@@ -328,7 +315,7 @@ void FileTypeDetails::slotAskSaveToggled(bool askSave)
     }
 
     m_mimeTypeData->setAskSave(askSave);
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void FileTypeDetails::setMimeTypeData(MimeTypeData *mimeTypeData, TypesListItem *item)
